==> haskell-bytestring-encoding-0.1.2.0-182.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-encoding
version:              0.1.2.0
visibility:           public
id:                   bytestring-encoding-0.1.2.0-IHHoeQjkS1SFTmzP0zz9Ce
key:                  bytestring-encoding-0.1.2.0-IHHoeQjkS1SFTmzP0zz9Ce
license:              BSD-3-Clause
copyright:            2018 Masahiro Sakai
maintainer:           masahiro.sakai@gmail.com
author:               Masahiro Sakai
homepage:             https://github.com/msakai/bytestring-encoding#readme
synopsis:             ByteString ↔ Text converter based on GHC.IO.Encoding
description:
    Please see the README on GitHub at <https://github.com/msakai/bytestring-encoding#readme>

category:             Data, Text
abi:                  e40fc3d112f610f1d2c3ac26acf8dd6d
exposed:              True
exposed-modules:
    Data.ByteString.Encoding Data.ByteString.Lazy.Encoding
    Data.ByteString.Lazy.Encoding.Internal

hidden-modules:       Paths_bytestring_encoding
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bytestring-encoding-0.1.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bytestring-encoding-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bytestring-encoding-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-encoding
hs-libraries:         HSbytestring-encoding-0.1.2.0-IHHoeQjkS1SFTmzP0zz9Ce
depends:              base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-encoding/html/bytestring-encoding.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-encoding/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-encoding-0.1.2.0-183-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-encoding
version:              0.1.2.0
visibility:           public
id:                   bytestring-encoding-0.1.2.0-EiwrxJwSHBDBBbC7KBmoZS
key:                  bytestring-encoding-0.1.2.0-EiwrxJwSHBDBBbC7KBmoZS
license:              BSD-3-Clause
copyright:            2018 Masahiro Sakai
maintainer:           masahiro.sakai@gmail.com
author:               Masahiro Sakai
homepage:             https://github.com/msakai/bytestring-encoding#readme
synopsis:             ByteString ↔ Text converter based on GHC.IO.Encoding
description:
    Please see the README on GitHub at <https://github.com/msakai/bytestring-encoding#readme>

category:             Data, Text
abi:                  e9106e707904338d01de87b2da564c2a
exposed:              True
exposed-modules:
    Data.ByteString.Encoding Data.ByteString.Lazy.Encoding
    Data.ByteString.Lazy.Encoding.Internal

hidden-modules:       Paths_bytestring_encoding
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bytestring-encoding-0.1.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bytestring-encoding-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bytestring-encoding-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-encoding
hs-libraries:         HSbytestring-encoding-0.1.2.0-EiwrxJwSHBDBBbC7KBmoZS
depends:              base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-encoding/html/bytestring-encoding.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-encoding/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
